@@ -2,7 +2,7 @@
 import sys
 from setuptools import setup
 
-VERSION = '0.0.2'
+VERSION = '0.0.3'
 DESCRIPTION = "AY250 HW3: evaluate string expressions with numexpr and Wolfram Alpha."
 
 CLASSIFIERS = list(filter(None, map(str.strip,
@@ -36,5 +36,5 @@ setup(
         platforms=['any'],
         setup_requires=['pytest-runner'],
         tests_require=['pytest'],
-        install_requires=['numexpr', 'urllib.request', 'argparse','math']
+        install_requires=['numexpr', 'argparse']
 )
\ No newline at end of file
